package top.yexuejc.demo;

import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

import top.yexuejc.demo.core.WebServer;

/**
 * @author maxiaofeng
 * @date 2025/7/11 13:56
 */
public class AppConfig {
    private static Properties properties = new Properties();
    private static boolean loaded = false;

    public static Properties getProperties() {
        if (!loaded) {
            loaded = true;
            try {
                loadDefaultConfig();
            } catch (Exception e) {
                throw new RuntimeException(e);
            }
        }
        return properties;
    }

    /**
     * 配置加载,同key不覆蓋
     */
    public static void loadAfter(Properties p) {
        p.putAll(properties);
        properties = p;
    }

    public static void put(String key, String value) {
        properties.put(key, value);
    }

    public static synchronized void loadDefaultConfig() throws Exception {
        loadConfig("classpath:application.properties");
    }

    public static Properties loadConfig(String path) throws Exception {
        if (path.startsWith("classpath:")) {
            // classpath:application.properties
            try (InputStream inputStream = WebServer.class.getClassLoader().getResourceAsStream(path.substring(10))) {
                Properties properties = new Properties();
                properties.load(inputStream);
                AppConfig.loadAfter(properties);
            } catch (IOException e) {
                throw new Exception(e);
            }
        } else {
            // /home/app/application.properties
            try (InputStream inputStream = new FileInputStream(path)) {
                Properties properties = new Properties();
                properties.load(inputStream);
                AppConfig.loadAfter(properties);
            } catch (IOException e) {
                throw new Exception(e);
            }
        }
        return AppConfig.properties;
    }
}
