package top.yexuejc.demo.config;

import java.util.List;

import jakarta.servlet.http.HttpServletRequest;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.validation.BindingResult;
import org.springframework.validation.ObjectError;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestControllerAdvice;
import org.springframework.web.servlet.ModelAndView;

/**
 * @author maxiaofeng
 * @date 2025/7/3 18:27
 */
@RestControllerAdvice
public class GlobalExceptionHandler {
    private static final Logger log = LoggerFactory.getLogger(GlobalExceptionHandler.class);

    @ExceptionHandler(MethodArgumentNotValidException.class)
    public Object handleValidationExceptions(MethodArgumentNotValidException ex, HttpServletRequest request) {

        log.error("参数校验异常: ", ex);

        BindingResult result = ex.getBindingResult();
        List<String> errorMessages = result.getAllErrors().stream().map(ObjectError::getDefaultMessage).toList();

        if (request.getContentType() != null && request.getContentType().contains("application/json")) {
            // 返回 JSON 错误信息
            return new ResponseEntity<>(errorMessages, HttpStatus.BAD_REQUEST);
        } else {
            // 返回错误页面或重定向到原页面
            ModelAndView modelAndView = new ModelAndView("login"); // 示例页面名
            modelAndView.addObject("error", errorMessages);
            return modelAndView;
        }
    }
}
